<?php

namespace Litecms\Exchangeorder\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Exchangeorder\Interfaces\ExchangeorderRepositoryInterface;

class ExchangeorderPublicController extends BaseController
{
    // use ExchangeorderWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Exchangeorder\Interfaces\ExchangeorderRepositoryInterface $exchangeorder
     *
     * @return type
     */
    public function __construct(ExchangeorderRepositoryInterface $exchangeorder)
    {
        $this->repository = $exchangeorder;
        parent::__construct();
    }

    /**
     * Show exchangeorder's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $exchangeorders = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$exchangeorder::$exchangeorder.names'))
            ->view('$exchangeorder::public.exchangeorder.index')
            ->data(compact('$exchangeorders'))
            ->output();
    }

    /**
     * Show exchangeorder's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $exchangeorders = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$exchangeorder::$exchangeorder.names'))
            ->view('$exchangeorder::public.exchangeorder.index')
            ->data(compact('$exchangeorders'))
            ->output();
    }

    /**
     * Show exchangeorder.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $exchangeorder = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$exchangeorder->name . trans('$exchangeorder::$exchangeorder.name'))
            ->view('$exchangeorder::public.exchangeorder.show')
            ->data(compact('$exchangeorder'))
            ->output();
    }

}
