<?php

namespace Litecms\Exchangeorder\Workflow;

use Litecms\Exchangeorder\Models\Exchangeorder;
use Validator;

class ExchangeorderValidator
{

    /**
     * Determine if the given exchangeorder is valid for complete status.
     *
     * @param Exchangeorder $exchangeorder
     *
     * @return bool / Validator
     */
    public function complete(Exchangeorder $exchangeorder)
    {
        return Validator::make($exchangeorder->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given exchangeorder is valid for verify status.
     *
     * @param Exchangeorder $exchangeorder
     *
     * @return bool / Validator
     */
    public function verify(Exchangeorder $exchangeorder)
    {
        return Validator::make($exchangeorder->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given exchangeorder is valid for approve status.
     *
     * @param Exchangeorder $exchangeorder
     *
     * @return bool / Validator
     */
    public function approve(Exchangeorder $exchangeorder)
    {
        return Validator::make($exchangeorder->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given exchangeorder is valid for publish status.
     *
     * @param Exchangeorder $exchangeorder
     *
     * @return bool / Validator
     */
    public function publish(Exchangeorder $exchangeorder)
    {
        return Validator::make($exchangeorder->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given exchangeorder is valid for archive status.
     *
     * @param Exchangeorder $exchangeorder
     *
     * @return bool / Validator
     */
    public function archive(Exchangeorder $exchangeorder)
    {
        return Validator::make($exchangeorder->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given exchangeorder is valid for unpublish status.
     *
     * @param Exchangeorder $exchangeorder
     *
     * @return bool / Validator
     */
    public function unpublish(Exchangeorder $exchangeorder)
    {
        return Validator::make($exchangeorder->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
